# AffiliationGroupV30EmploymentSummaryV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30**](LastModifiedDateV30.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30**](ExternalIDsV30.md) |  | [optional] 
**summaries** | [**list[EmploymentSummaryV30]**](EmploymentSummaryV30.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

